@@ -8,6 +8,8 @@
 #ifndef ASSUME_H
 #define	ASSUME_H
 
+#include <string>
+
 namespace GiNaC {
 
 void assume(ex rel);
@@ -15,6 +17,8 @@ void assume(ex x, char* flag_desc);
 void forget(ex rel);
 void forget(ex x, char* flag_desc);
 
+void set_state(const std::string&, bool);
+
 } // namespace GiNaC
 
 #endif	/* ASSUME_H */
